pub struct GetParam {
pub drawable: Drawable,
pub param: u32,
}Expand description
The GetParam request.
This request replies GetParamReply.
Associated cookie types are GetParamCookie and GetParamCookieUnchecked.
Fields
drawable: Drawableparam: u32Trait Implementations
Sourceimpl RawRequest for GetParam
impl RawRequest for GetParam
Sourcefn raw_request(&self, c: &Connection, checked: bool) -> u64
fn raw_request(&self, c: &Connection, checked: bool) -> u64
Actual implementation of the request sending Read more
Sourceimpl RequestWithReply for GetParam
impl RequestWithReply for GetParam
Sourcetype Reply = GetParamReply
type Reply = GetParamReply
Reply associated with the request
Sourcetype Cookie = GetParamCookie
type Cookie = GetParamCookie
Default cookie type for the request, as returned by Connection::send_request.
Sourcetype CookieUnchecked = GetParamCookieUnchecked
type CookieUnchecked = GetParamCookieUnchecked
Unchecked cookie type for the request, as returned by Connection::send_request_unchecked.