pub struct IsEnabled {
pub context_tag: ContextTag,
pub capability: u32,
}Expand description
The IsEnabled request.
This request replies IsEnabledReply.
Associated cookie types are IsEnabledCookie and IsEnabledCookieUnchecked.
Fields
context_tag: ContextTagcapability: u32Trait Implementations
Sourceimpl RawRequest for IsEnabled
impl RawRequest for IsEnabled
Sourcefn raw_request(&self, c: &Connection, checked: bool) -> u64
fn raw_request(&self, c: &Connection, checked: bool) -> u64
Actual implementation of the request sending Read more
Sourceimpl RequestWithReply for IsEnabled
impl RequestWithReply for IsEnabled
Sourcetype Reply = IsEnabledReply
type Reply = IsEnabledReply
Reply associated with the request
Sourcetype Cookie = IsEnabledCookie
type Cookie = IsEnabledCookie
Default cookie type for the request, as returned by Connection::send_request.
Sourcetype CookieUnchecked = IsEnabledCookieUnchecked
type CookieUnchecked = IsEnabledCookieUnchecked
Unchecked cookie type for the request, as returned by Connection::send_request_unchecked.