pub struct QueryContext {
pub context: Context,
}Expand description
The QueryContext request.
This request replies QueryContextReply.
Associated cookie types are QueryContextCookie and QueryContextCookieUnchecked.
Fields
context: ContextTrait Implementations
Sourceimpl Clone for QueryContext
impl Clone for QueryContext
Sourcefn clone(&self) -> QueryContext
fn clone(&self) -> QueryContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryContext
impl Debug for QueryContext
Sourceimpl RawRequest for QueryContext
impl RawRequest for QueryContext
Sourcefn raw_request(&self, c: &Connection, checked: bool) -> u64
fn raw_request(&self, c: &Connection, checked: bool) -> u64
Actual implementation of the request sending Read more
Sourceimpl Request for QueryContext
impl Request for QueryContext
Sourceimpl RequestWithReply for QueryContext
impl RequestWithReply for QueryContext
Sourcetype Reply = QueryContextReply
type Reply = QueryContextReply
Reply associated with the request
Sourcetype Cookie = QueryContextCookie
type Cookie = QueryContextCookie
Default cookie type for the request, as returned by Connection::send_request.
Sourcetype CookieUnchecked = QueryContextCookieUnchecked
type CookieUnchecked = QueryContextCookieUnchecked
Unchecked cookie type for the request, as returned by Connection::send_request_unchecked.