pub struct ReadPixels {
pub context_tag: ContextTag,
pub x: i32,
pub y: i32,
pub width: i32,
pub height: i32,
pub format: u32,
pub type: u32,
pub swap_bytes: bool,
pub lsb_first: bool,
}Expand description
The ReadPixels request.
This request replies ReadPixelsReply.
Associated cookie types are ReadPixelsCookie and ReadPixelsCookieUnchecked.
Fields
context_tag: ContextTagx: i32y: i32width: i32height: i32format: u32type: u32swap_bytes: boollsb_first: boolTrait Implementations
Sourceimpl Clone for ReadPixels
impl Clone for ReadPixels
Sourcefn clone(&self) -> ReadPixels
fn clone(&self) -> ReadPixels
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadPixels
impl Debug for ReadPixels
Sourceimpl RawRequest for ReadPixels
impl RawRequest for ReadPixels
Sourcefn raw_request(&self, c: &Connection, checked: bool) -> u64
fn raw_request(&self, c: &Connection, checked: bool) -> u64
Actual implementation of the request sending Read more
Sourceimpl Request for ReadPixels
impl Request for ReadPixels
Sourceimpl RequestWithReply for ReadPixels
impl RequestWithReply for ReadPixels
Sourcetype Reply = ReadPixelsReply
type Reply = ReadPixelsReply
Reply associated with the request
Sourcetype Cookie = ReadPixelsCookie
type Cookie = ReadPixelsCookie
Default cookie type for the request, as returned by Connection::send_request.
Sourcetype CookieUnchecked = ReadPixelsCookieUnchecked
type CookieUnchecked = ReadPixelsCookieUnchecked
Unchecked cookie type for the request, as returned by Connection::send_request_unchecked.