pub struct GetDeviceFocus {
pub device_id: u8,
}Expand description
The GetDeviceFocus request.
This request replies GetDeviceFocusReply.
Associated cookie types are GetDeviceFocusCookie and GetDeviceFocusCookieUnchecked.
Fields
device_id: u8Trait Implementations
Sourceimpl Clone for GetDeviceFocus
impl Clone for GetDeviceFocus
Sourcefn clone(&self) -> GetDeviceFocus
fn clone(&self) -> GetDeviceFocus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetDeviceFocus
impl Debug for GetDeviceFocus
Sourceimpl RawRequest for GetDeviceFocus
impl RawRequest for GetDeviceFocus
Sourcefn raw_request(&self, c: &Connection, checked: bool) -> u64
fn raw_request(&self, c: &Connection, checked: bool) -> u64
Actual implementation of the request sending Read more
Sourceimpl Request for GetDeviceFocus
impl Request for GetDeviceFocus
Sourceimpl RequestWithReply for GetDeviceFocus
impl RequestWithReply for GetDeviceFocus
Sourcetype Reply = GetDeviceFocusReply
type Reply = GetDeviceFocusReply
Reply associated with the request
Sourcetype Cookie = GetDeviceFocusCookie
type Cookie = GetDeviceFocusCookie
Default cookie type for the request, as returned by Connection::send_request.
Sourcetype CookieUnchecked = GetDeviceFocusCookieUnchecked
type CookieUnchecked = GetDeviceFocusCookieUnchecked
Unchecked cookie type for the request, as returned by Connection::send_request_unchecked.