pub struct OpenDevice {
pub device_id: u8,
}Expand description
The OpenDevice request.
This request replies OpenDeviceReply.
Associated cookie types are OpenDeviceCookie and OpenDeviceCookieUnchecked.
Fields
device_id: u8Trait Implementations
Sourceimpl Clone for OpenDevice
impl Clone for OpenDevice
Sourcefn clone(&self) -> OpenDevice
fn clone(&self) -> OpenDevice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenDevice
impl Debug for OpenDevice
Sourceimpl RawRequest for OpenDevice
impl RawRequest for OpenDevice
Sourcefn raw_request(&self, c: &Connection, checked: bool) -> u64
fn raw_request(&self, c: &Connection, checked: bool) -> u64
Actual implementation of the request sending Read more
Sourceimpl Request for OpenDevice
impl Request for OpenDevice
Sourceimpl RequestWithReply for OpenDevice
impl RequestWithReply for OpenDevice
Sourcetype Reply = OpenDeviceReply
type Reply = OpenDeviceReply
Reply associated with the request
Sourcetype Cookie = OpenDeviceCookie
type Cookie = OpenDeviceCookie
Default cookie type for the request, as returned by Connection::send_request.
Sourcetype CookieUnchecked = OpenDeviceCookieUnchecked
type CookieUnchecked = OpenDeviceCookieUnchecked
Unchecked cookie type for the request, as returned by Connection::send_request_unchecked.