pub struct ListComponents {
pub device_spec: DeviceSpec,
pub max_names: u16,
}Expand description
The ListComponents request.
This request replies ListComponentsReply.
Associated cookie types are ListComponentsCookie and ListComponentsCookieUnchecked.
Fields
device_spec: DeviceSpecmax_names: u16Trait Implementations
Sourceimpl Clone for ListComponents
impl Clone for ListComponents
Sourcefn clone(&self) -> ListComponents
fn clone(&self) -> ListComponents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListComponents
impl Debug for ListComponents
Sourceimpl RawRequest for ListComponents
impl RawRequest for ListComponents
Sourcefn raw_request(&self, c: &Connection, checked: bool) -> u64
fn raw_request(&self, c: &Connection, checked: bool) -> u64
Actual implementation of the request sending Read more
Sourceimpl Request for ListComponents
impl Request for ListComponents
Sourceimpl RequestWithReply for ListComponents
impl RequestWithReply for ListComponents
Sourcetype Reply = ListComponentsReply
type Reply = ListComponentsReply
Reply associated with the request
Sourcetype Cookie = ListComponentsCookie
type Cookie = ListComponentsCookie
Default cookie type for the request, as returned by Connection::send_request.
Sourcetype CookieUnchecked = ListComponentsCookieUnchecked
type CookieUnchecked = ListComponentsCookieUnchecked
Unchecked cookie type for the request, as returned by Connection::send_request_unchecked.